==> krb-v0.15.0.tar.gz: krb-v0.15.0/src/krb_public.ml <==
module Stable = struct
  module Conn_type = Conn_type.Stable
  module Cross_realm_principal_name = Cross_realm_principal_name.Stable
  module Server_key_source = Server_key_source.Stable
  module Keytab = Keytab.Stable
  module Mode = Mode.Stable
  module Principal = Principal.Stable
end

open Import
module Async_protocol = Async_protocol
module Authorize = Authorize
module Client_identity = Client_identity
module Client_principal = Client_principal
module Conn_type = Conn_type
module Conn_type_preference = Conn_type_preference
module Cred_cache = Cred_cache
module Cross_realm_principal_name = Cross_realm_principal_name
module Fqdn = Fqdn
module Internal = Internal
module Kerberized_rw = Kerberized_rw
module Server_key_source = Server_key_source
module Keytab = Keytab
module On_credential_forwarding_request = On_credential_forwarding_request
module Mode = Mode
module Persistent_rpc_client = Persistent_rpc_client
module Principal = Principal
module Realm = Realm
module Rpc = Kerberized_rpc
module Server_principal = Server_principal
module Tcp = Kerberized_tcp
module Tgt = Tgt

module Private = struct
  module Protocol = Protocol
  module Protocol_with_test_mode = Protocol_with_test_mode
  module Protocol_backend_intf = Protocol_backend_intf
  module Test_mode_protocol = Test_mode_protocol
  module Client_cred_cache = Client_cred_cache
  module Currently_running_user = Currently_running_user
  module Kerberized_rpc_transport = Kerberized_rpc_transport
  module Kerberized_tcp_over_protocol = Kerberized_tcp_over_protocol
  module Kerberized_rpc_over_protocol = Kerberized_rpc_over_protocol
end

==> krb-v0.16.0.tar.gz: krb-v0.16.0/src/krb_public.ml <==
module Stable = struct
  module Conn_type = Conn_type.Stable
  module Cross_realm_principal_name = Cross_realm_principal_name.Stable
  module Server_key_source = Server_key_source.Stable
  module Keytab = Keytab.Stable
  module Mode = Mode.Stable
  module Principal = Principal.Stable
end

open Import
module Async_protocol = Async_protocol
module Authorize = Authorize
module Client_identity = Client_identity
module Client_principal = Client_principal
module Conn_type = Conn_type
module Conn_type_preference = Conn_type_preference
module Cred_cache = Cred_cache
module Cross_realm_principal_name = Cross_realm_principal_name
module Fqdn = Fqdn
module Handshake_error = Handshake_error
module Internal = Internal
module Kerberized_rw = Kerberized_rw
module Server_key_source = Server_key_source
module Keytab = Keytab
module On_credential_forwarding_request = On_credential_forwarding_request
module Mode = Mode
module Persistent_versioned_rpc_client = Persistent_rpc_client.Versioned_rpc
module Persistent_rpc_client = Persistent_rpc_client.Rpc
module Principal = Principal
module Realm = Realm
module Rpc = Kerberized_rpc
module Server_principal = Server_principal
module Tcp = Kerberized_tcp
module Tgt = Tgt

module Private = struct
  module Protocol = Protocol
  module Protocol_with_test_mode = Protocol_with_test_mode
  module Protocol_backend_intf = Protocol_backend_intf
  module Test_mode_protocol = Test_mode_protocol
  module Client_cred_cache = Client_cred_cache
  module Currently_running_user = Currently_running_user
  module Kerberized_rpc_transport = Kerberized_rpc_transport
  module Kerberized_tcp_over_protocol = Kerberized_tcp_over_protocol
  module Kerberized_rpc_over_protocol = Kerberized_rpc_over_protocol
end
